import React, {useState, useCallback, useEffect} from 'react';
import ReactDOM from 'react-dom';
import { csv, scaleBand, scaleLinear, max, formatPower  } from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';

const width = 960;
const height = 500;
const margin = {top: 50, right:50, bottom:50, left: 100};


const App = () => {
  
  const data = useData();

  if (!data) {
    return <pre>Loading...</pre>;
  }
    
  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;
  
  const yValue = d => d.Zona;
  const xValue = d => d.Month;

  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight]);

  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerWidth]);
  
  console.log("X Scale Ticks:", xScale.ticks(5));
    console.log("Y Scale Ticks:", yScale.domain());
  
  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        <AxisBottom xScale={xScale} innerHeight={innerHeight} />
        <AxisLeft  yScale={yScale} />
        <Marks 
          data={data} 
          xScale={xScale} 
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          />
      </g>
    </svg>
  );
};


const rootElement = document.getElementById('root');
  
ReactDOM.render(<App />, rootElement);